==> server-23.3.0-1108.535-sources.jar: com/xebialabs/deployit/server/jetty/JettyServerConnector.java <==
package com.xebialabs.deployit.server.jetty;

import com.xebialabs.deployit.ServerConfiguration;
import com.xebialabs.deployit.util.SslFactoryBuilder;
import org.eclipse.jetty.http.HttpCompliance;
import org.eclipse.jetty.server.HttpConfiguration;
import org.eclipse.jetty.server.HttpConnectionFactory;
import org.eclipse.jetty.server.SecureRequestCustomizer;
import org.eclipse.jetty.server.ServerConnector;
import org.eclipse.jetty.util.ssl.SslContextFactory;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.web.embedded.jetty.JettyServerCustomizer;

import java.util.concurrent.TimeUnit;

import static com.xebialabs.deployit.ServerConfiguration.DEFAULT_STOP_TIMEOUT;

class JettyServerConnector {

    public static JettyServerCustomizer create(ServerConfiguration serverConfiguration) {
        return jettyServer -> {
            jettyServer.setStopTimeout(DEFAULT_STOP_TIMEOUT);

            ServerConnector connector;
            if (serverConfiguration.isSsl()) {
                logger.debug("Setting up Jetty to use SSL");
                SslContextFactory.Server sslContextFactory = SslFactoryBuilder.build(serverConfiguration);
                HttpConnectionFactory httpConnectionFactory = getHttpConnectionFactory();
                connector = new ServerConnector(jettyServer, sslContextFactory, httpConnectionFactory);
            } else {
                HttpConnectionFactory httpConnectionFactory = getHttpConnectionFactory();
                connector = new ServerConnector(jettyServer, httpConnectionFactory);
            }

            connector.setIdleTimeout(serverConfiguration.getHttpIdleTimeoutMillis());
            connector.setHost(serverConfiguration.getHttpBindAddress());
            connector.setPort(serverConfiguration.getHttpPort());

            jettyServer.setConnectors(new ServerConnector[]{connector});
            logger.info("Connector listen {} on {}:{}", serverConfiguration.isSsl() ? "secure" : "no-secure", connector.getHost(), connector.getPort());
        };
    }

    private static HttpConnectionFactory getHttpConnectionFactory() {
        HttpConfiguration configuration = new HttpConfiguration();
        configuration.addCustomizer(new SecureRequestCustomizer(
                true,
                TimeUnit.SECONDS.convert(365, TimeUnit.DAYS),
                true
        ));
        HttpConnectionFactory httpConnectionFactory = new HttpConnectionFactory(configuration);
        httpConnectionFactory.getHttpConfiguration().setHttpCompliance(HttpCompliance.RFC2616);
        httpConnectionFactory.getHttpConfiguration().setSendServerVersion(false);
        return httpConnectionFactory;
    }

    private static final Logger logger = LoggerFactory.getLogger(JettyServerConnector.class);
}

==> server-23.3.7-sources.jar: com/xebialabs/deployit/server/jetty/JettyServerConnector.java <==
package com.xebialabs.deployit.server.jetty;

import com.xebialabs.deployit.ServerConfiguration;
import com.xebialabs.deployit.util.SslFactoryBuilder;
import org.eclipse.jetty.http.HttpCompliance;
import org.eclipse.jetty.server.HttpConfiguration;
import org.eclipse.jetty.server.HttpConnectionFactory;
import org.eclipse.jetty.server.SecureRequestCustomizer;
import org.eclipse.jetty.server.ServerConnector;
import org.eclipse.jetty.util.ssl.SslContextFactory;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.web.embedded.jetty.JettyServerCustomizer;

import java.util.concurrent.TimeUnit;

import static com.xebialabs.deployit.ServerConfiguration.DEFAULT_STOP_TIMEOUT;

class JettyServerConnector {

    public static JettyServerCustomizer create(ServerConfiguration serverConfiguration) {
        return jettyServer -> {
            jettyServer.setStopTimeout(DEFAULT_STOP_TIMEOUT);

            ServerConnector connector;
            if (serverConfiguration.isSsl()) {
                logger.debug("Setting up Jetty to use SSL");
                SslContextFactory.Server sslContextFactory = SslFactoryBuilder.build(serverConfiguration);
                HttpConnectionFactory httpConnectionFactory = getHttpConnectionFactory();
                connector = new ServerConnector(jettyServer, sslContextFactory, httpConnectionFactory);
            } else {
                HttpConnectionFactory httpConnectionFactory = getHttpConnectionFactory();
                connector = new ServerConnector(jettyServer, httpConnectionFactory);
            }

            connector.setIdleTimeout(serverConfiguration.getHttpIdleTimeoutMillis());
            connector.setHost(serverConfiguration.getHttpBindAddress());
            connector.setPort(serverConfiguration.getHttpPort());

            jettyServer.setConnectors(new ServerConnector[]{connector});
            logger.info("Connector listen {} on {}:{}", serverConfiguration.isSsl() ? "secure" : "no-secure", connector.getHost(), connector.getPort());
        };
    }

    private static HttpConnectionFactory getHttpConnectionFactory() {
        HttpConfiguration configuration = new HttpConfiguration();
        configuration.addCustomizer(new SecureRequestCustomizer(
                true,
                TimeUnit.SECONDS.convert(365, TimeUnit.DAYS),
                true
        ));
        HttpConnectionFactory httpConnectionFactory = new HttpConnectionFactory(configuration, HttpCompliance.RFC2616);
        httpConnectionFactory.getHttpConfiguration().setSendServerVersion(false);
        return httpConnectionFactory;
    }

    private static final Logger logger = LoggerFactory.getLogger(JettyServerConnector.class);
}
